@@ -432,7 +432,11 @@ class Window( QMainWindow):
               if language == 'python':
                 fileHandle.write("python \'"+unicode(self.editor.filename).encode('utf-8') + "\'\n")
               elif language == 'qml':
-                fileHandle.write("/opt/qt4-maemo5/bin/qmlviewer \'"+unicode(self.editor.filename).encode('utf-8') + "\' -fullscreen\n")             
+                fileHandle.write("qmlviewer \'"+unicode(self.editor.filename).encode('utf-8') + "\' -fullscreen\n")      
+              elif language in ('c', 'cpp'):
+                fileHandle.write("make %s\nchmod +x %s\n./%s" % (unicode(self.editor.filename).encode('utf-8'),\
+                                                                 unicode(self.editor.filename).encode('utf-8'),\
+                                                                 unicode(self.editor.filename).encode('utf-8')))       
               elif language != None:
                 fileHandle.write(language+" \'"+unicode(self.editor.filename).encode('utf-8') + "\' \n")
               else:
@@ -442,7 +446,7 @@ class Window( QMainWindow):
               fileHandle.close()
           except (IOError, OSError), e:
              QMessageBox.warning(self, "KhtEditor -- Execute Error",
-                    "Failed to write launch script %s: %s" % (filename, e))
+                    "Failed to write launch script %s: %s" % (self.editor.filename, e))
           commands.getoutput("chmod 777 /tmp/khteditor.tmp")
           Popen('/usr/bin/osso-xterm /tmp/khteditor.tmp',shell=True,stdout=None)
 
